[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - doapfiend.utils.NotFoundError: DOAP not found
  - doapfiend.cli.DoapFiend: `DoapFiend` class
  - doapfiend.utils.DoapPrinter: Prints DOAP in human readable text
  - doapfiend.utils.rdfSubject
    - doapfiend.model.CVSRepository: CVS repository class
    - doapfiend.model.Project: DOAP Project Class
    - doapfiend.model.Release: A release class
    - doapfiend.model.SVNRepository: Subversion repository classs